package com_taovip.vsms_demo;

import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

import org.apache.http.client.ClientProtocolException;
import org.junit.Before;
import org.junit.Test;

import com.google.gson.Gson;
import com.yunpian.sdk.YunpianClient;
import com.yunpian.sdk.api.VideoSmsApi;
import com.yunpian.sdk.model.Result;
import com.yunpian.sdk.model.Template;
import com.yunpian.sdk.model.VideoLayout;
import com.yunpian.sdk.model.VideoLayout.FrameData;
import com.yunpian.sdk.model.VideoLayout.VideoFrame;

import com_taovip.vsms_demo.resp.VsmsTemplateResp;


/**
 * 模板提审环节demo
 * <p>	模板上传为发送视频短信的第一步
 * <p>	模板上传 / 审核通过后即可根据模板给号码发送视频短信
 * 
 * <p>	短信模板为一个zip包 + 一段布局json
 * <p>	zip包中包含模板需要用到的所有文件（文本，图片，视频）
 * <p>	布局json描述这些文件的位置关系
 * 
 * <p>	zip包说明：
 * <p>		- zip包中不允许出现文件夹
 * <p>		- zip包在400k ~ 1.9Mb之间，按照1k = 1024b换算
 * 
 * @author luoyi
 *
 */
public class TplTest {

	
	//	yunpian sdk
	protected YunpianClient ypClient;
	//	视频短信api
	protected VideoSmsApi api;
	
	protected Gson gson;
	
	
	@Before
	public void init() {
		ypClient = new YunpianClient(Commons.APIKEY);
		ypClient.init();
        api = new VideoSmsApi();
        api.init(ypClient);
        
        gson = new Gson();
	}
	
	/**
	 * 测试上传模板
	 */
	@Test
	public void testTemplateSubmit() {
		//	准备参数
		Map<String, String> param = new HashMap<String, String>();
        param.put(YunpianClient.APIKEY, Commons.APIKEY);			//	调用sdk的apikey，实际使用时请使用自己的apikey
        param.put(YunpianClient.SIGN, "【EW测试用】");					//	短信签名，实际使用时请替换成自己的签名（签名报备请参考官网：官网 -> 通讯云 -> 国内短信 -> 签名/模板报备 中的签名管理）
        
        //	模板布局（控制视频短信中文本，图片，视频的位置关系）
        VideoLayout layout = new VideoLayout();
        layout.setSubject("Yunpian演示");							//	视频短信标题
        
        
        VideoFrame frame1 = new VideoFrame().setIndex(2);								//	视频短信第一部分frame，位置定义setIndex(1)
        FrameData data1 = new FrameData().setIndex(1).setFileName("1test-utf8.txt");	//	第一部分为一段文本，文本包含在txt文件中，且txt必须为UTF-8编码。这里的文件名必须与zip包中的文件名对应
        frame1.setAttachments(Arrays.asList(data1));									//	将刚刚定义的图片加入frame
	
        VideoFrame frame2 = new VideoFrame().setIndex(1);								//	视频短信第二部分frame，位置定义setIndex(2)
        FrameData data2 = new FrameData().setIndex(1).setFileName("2test.mp4");			//	第二部分为一段视频
        frame2.setAttachments(Arrays.asList(data2));									//	将刚刚定义的文本加入frame
        
        layout.setFrames(Arrays.asList(frame1, frame2));			//	将签名定义的frame加入到视频短信布局中，frame按照自己的setIndex顺序
        
        //	参数中追加刚刚定义的布局
        String json = layout.toString();
        param.put("layout", json);
        
        //	读取模板zip包
        InputStream in = TplTest.class.getResourceAsStream("/files/demo.zip");
        byte[] bytes = null;
		try {
			bytes = new byte[in.available()];
			in.read(bytes);
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		//	请求视频短信模板上传sdk
		Result<Template> res = api.addTpl(param, layout.toString(), bytes);
        System.out.println(res.getCode() + " " + res.getDetail() + " " + res.getMsg());	//	打印返回值，返回0 null OK即说明上传成功。成功后即可在 官网 -> 通讯云 -> 更多产品 -> 视频短信 -> 视频短信模板 中看到刚刚申请的模板
        if (res.getThrowable() != null) {												//	万一出错了。。。
        	res.getThrowable().printStackTrace();
        }
	}
	
	
	/**
	 * 测试模板状态查询
	 */
	@Test
	public void testTemplateQuery() {
		Map<String, Object> param = new HashMap<String, Object>();
        param.put(YunpianClient.APIKEY, Commons.APIKEY);			//	调用sdk的apikey，实际使用时请使用自己的apikey
        param.put("tpl_id", "998");									//	模板id
        
        try {
			String resp = HttpUtils.query("https://vsms.yunpian.com/v2/vsms/get_tpl.json", param);
			System.out.println(resp);

			VsmsTemplateResp vsmsTemplateResp = gson.fromJson(resp, VsmsTemplateResp.class);
			System.out.println(vsmsTemplateResp.getCode() + " " + vsmsTemplateResp.getMsg());
			if (vsmsTemplateResp.getData() != null) {
				System.out.println("模板id：" + vsmsTemplateResp.getData().getTpl_id()
									+ " 移动是否可发：" + vsmsTemplateResp.getData().isYd_enabled()
									+ " 联通是否可发：" + vsmsTemplateResp.getData().isLt_enabled()
									+ " 电信是否可发：" + vsmsTemplateResp.getData().isDx_enabled());
			}
        } catch (ClientProtocolException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	
}
